;#######################################################
#NoEnv
SendMode Input
SetTitleMatchMode, RegEx

;/* The actual key presses that are sent to the game to manipulate.
; * We should map these keys to crouch and ironsights in the game's control
; * configs for our bindings to actually work.
; * You can change these (the characters inside quotes) if you wish
; * to use other keys/buttons for the commands
; */
CrouchSwitch := "[" ;// Turns on/off extra crouchkey functionality
SightSwitch := "]" ;// Turns on/off sight toggle functionality
CrouchKey := "c"  ;// Key bound in game to Crouch
NewCrouchKey := "LControl"  ;// Key used for "non-toggle" crouch
SightKey := ","  ;// Key bound in game for iron Sights
NewSightKey := "RButton" ;// Key we will use for iron sights


;/* Variables to enable/disable our hotkey toggles */
sightToggleEnabled := 0
crouchToggleEnabled := 0

;/* Variables to keep track of our toggle states, both for crouching, and
; * also iron sights */
crouching := 0 ;// we are currently in the crouched state
crouchOverride := 0 ;// Handles special case where built in crouch overrides new
sighting := 0  ;// we are currently sighting down the gun


;Define Hotkeys so that they are only Active when running FarCry2 application
;=======================================================
;=======================================================
Hotkey, IfWinActive, ahk_class Nomad* ;// Only active when class matches Nomad
  
  ;// The key/button presses that will trigger our AHK script
  Hotkey, %CrouchSwitch% , CrouchEnableInput
  Hotkey, %SightSwitch% , SightEnableInput
  Hotkey, *%NewSightKey%, SightKeyInput
  Hotkey, *%NewCrouchKey% , CrouchKeyInputPressed
  Hotkey, *%NewCrouchKey% Up , CrouchKeyInputReleased
  Hotkey, *%CrouchKey%, NormalCrouchKeyInput
  
  
return


;/* Toggle the Crouch hotkeys on/off. When "on" hotkey replacement happens, when off
; * the keys/buttons are sent to the game unaltered.
; */
CrouchEnableInput:
    
    if (crouchToggleEnabled)
    {
        crouchToggleEnabled := 0 ;// Turn off TS hotkey
        crouching := 0
        
    }
    else ;// (!crouchToggleEnabled)
    {
        crouchToggleEnabled := 1 ;// Turn on TS hotkey
        
    }

    return


;/* Toggle the Sight hotkeys on/off. When "on" hotkey replacement happens, when off
; * the keys/buttons are sent to the game unaltered
; */
SightEnableInput:
    
    if (sightToggleEnabled)
    {
        sightToggleEnabled := 0 ;// Turn off crouch toggle hotkey
        sighting := 0
        
    }
    else
    {
        sightToggleEnabled := 1 ;// Turn on crouch toggle hotkey
        
    }

    return





;/* Implement sight toggle functionality. Rather than having to hold the sight
; * button down, you press once to look down the iron sights, and press again to
; * to stop sighting. Care must be taken to maintain the current sighted state
; * (ie. effectively whether the "Button" is being held down or not) */
SightKeyInput:
    
    if (sightToggleEnabled && sighting) ; // We are using sights and should stop
    {
        sighting := 0
        Send {%SightKey% up}        
    }
    else if (sightToggleEnabled) ;// sighting = 0, ie not sighting
    {   
        keywait %SightKey% ;// Wait for button-up event to reach game, since it can't be supressed
        
        sighting := 1
        Send {%SightKey% down}
        
    }

    else ;// Sight toggle disabled. We still need to keep track of state
    {   
        
        ;/* Send the keys as is, let the game handled it */
        sighting := 1
        send {%SightKey% down} ;// User already pressed key, so send to game
        keywait %SightKey% ;// User let go

        sighting := 0
        send {%SightKey% up} ;// Send the "let go of key" to the game
    }


    return




;/* We need to keep track of whether or not the character is crouching when
; * normal (toggled) crouch key is used. This function handles that.
; */
NormalCrouchKeyInput:
    
    crouchKeyIsDown := GetKeyState(NewCrouchKey, "P")

    if (crouchToggleEnabled && crouching && crouchKeyIsDown) ;// Switch from dynamic crouch to toggled crouch but still stay crouching)
    {        
        crouchOverride := !(crouchOverride) ;// Stay crouched if we let go of new crouch button 

    }
    else if (crouching) ;// We are crouching, so record change and stand up
    {
        
        crouchOverride := 0
        crouching := 0
        Send {%CrouchKey%}

    } else ;// (!crouching) We are standing, so record change and crouch
    {
        crouching := 1
        Send {%CrouchKey%}

    }
    return


;/* Implement crouch toggle functionality. In this specific game crouch by
; * default is toggled. Ie. you press it once to crouch and once again to get up.
; * So we provide an additional key (the triggered key) to implement a non
; * crouched toggle where as soon as you let go of the key the character stops
; * crouching. So when the player presses the key a crouch toggle command is sent
; * to the game. When the player releases a key, another crouch toggle command is
; * sent. It might be possible for the presses to happen to fast and we may need
; * to account for that somehow.
; *
; * This specific function handles when we hold our new crouch key down
; * (and should be crouching)
; */
CrouchKeyInputPressed:
    
    ;/* If we are not crouching, then crouch. Anytime else ignore input */
    if (crouchToggleEnabled && crouching && crouchOverride) 
    {
        crouchOverride :=0
        keywait %NewCrouchKey%
    }
    else if (crouchToggleEnabled && !(crouching)) 
    {
        ;/* Start Crouching (Game turns toggle on) */
        crouchOverride := 0
        crouching := 1
        Send {%CrouchKey%}
        keywait %NewCrouchKey% ;// Prevent endless looping while key repeatrate is hit?
    }


    return


;/* Implement crouch toggle functionality. In this specific game crouch by
; * default is toggled. Ie. you press it once to crouch and once again to get up.
; * So we provide an additional key (the triggered key) to implement a non
; * crouched toggle where as soon as you let go of the key the character stops
; * crouching. So when the player presses the key a crouch toggle command is sent
; * to the game. When the player releases a key, another crouch toggle command is
; * sent. It might be possible for the presses to happen to fast and we may need
; * to account for that somehow.
; *
; * This specific function handles when we release our new crouch key
; * (and should stand up)
; */
CrouchKeyInputReleased:
    
    ;/* If we are crouching then stop. Anytime else do nothing */
    if (crouchToggleEnabled && crouching && !(crouchOverride)) 
    {
        ;/* Stop Crouching (Game turns toggle off) */
        crouching := 0
        Send {%CrouchKey%}
    }


    return
